From 8aa9ac3657733fda98040c487899c8e3169539bb Mon Sep 17 00:00:00 2001
From: David Lawrence Ramsey <pooka109@gmail.com>
Date: Wed, 24 May 2006 18:36:38 +0000
Subject: [PATCH] don't call wrap_reset() if we use verbatim input

git-svn-id: svn://svn.savannah.gnu.org/nano/trunk/nano@3558 35c25a1d-7b9e-4130-9fde-d3aeb78583b8
---
 src/nano.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/src/nano.c b/src/nano.c
index 4f4f8c7d..ece0195a 100644
--- a/src/nano.c
+++ b/src/nano.c
@@ -1334,9 +1334,11 @@ int do_input(bool *meta_key, bool *func_key, bool *s_or_t, bool
 	 * mode. */
 	 if (*s_or_t == TRUE || get_key_buffer_len() == 0) {
 #ifndef DISABLE_WRAPPING
-	    /* If we got a shortcut or toggle, turn off prepending of
-	     * wrapped text. */
-	    if (*s_or_t == TRUE)
+	    /* If we got a shortcut or toggle, and it's not the shortcut
+	     * for verbatim input, turn off prepending of wrapped
+	     * text. */
+	    if (*s_or_t == TRUE && (!have_shortcut || s == NULL ||
+		s->func != do_verbatim_input))
 		wrap_reset();
 #endif
 
-- 
GitLab